/* windows.h*/
/*
 * Copyright (c) 1999, 2000 Greg Haerr <greg@censoft.com>
 *
 * Microwindows Win32 API master header file
 */
#ifdef __cplusplus
extern "C" {
#endif

#include "device.h"
#include "list.h"
#include "windef.h"
#include "wingdi.h"
#include "winuser.h"
#include "winctl.h"

/* internal stuff for now*/
/* winuser.c*/
extern int	SYSMETRICS_CYCAPTION;
extern int	SYSMETRICS_CXDOUBLECLK;
extern int	SYSMETRICS_CYDOUBLECLK;

/* wingdi.c*/
extern BOOL	bERASEMOVE;	/* default repaint algorithm*/

/* external routines*/
int WINAPI 	WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
    			LPSTR lpCmdLine, int nShowCmd);

int		GsUserInit(int ac, char **av);

/* Internal Microwindows non-win32 definitions*/

/* GDI Objects*/

typedef struct {			/* GDI object hdr*/
	int		type;		/* OBJ_xxx type*/
	BOOL		stockobj;	/* TRUE if stock (unallocated) object*/
} GDIOBJHDR;

/* gdiobj*/
struct hgdiobj {
	GDIOBJHDR	hdr;		/* all gdi object start with this hdr*/
	/* additional data...*/		/* allocated per object type*/
};

typedef struct {
	GDIOBJHDR	hdr;
	int		style;		/* pen style*/
	COLORREF	color;		/* pen color*/
} PENOBJ;

typedef struct {
	GDIOBJHDR	hdr;
	int		style;		/* brush style*/
	COLORREF	color;		/* brush color*/
} BRUSHOBJ;

typedef struct {
	GDIOBJHDR	hdr;
	int		fontno;		/* driver font #*/
} FONTOBJ;

typedef struct {
	GDIOBJHDR	hdr;
	int		width;		/* width*/
	int		height;		/* height*/
	int		planes;		/* # planes*/
	int		bpp;		/* bits per pixel*/
	int		linelen;	/* bytes per line*/
	int		size;		/* allocated size in bytes*/
	char 		bits[1];	/* beginning of bitmap*/
} BITMAPOBJ;

typedef struct {
	GDIOBJHDR   	hdr;
	MWCLIPREGION  *	rgn;		/* clip region*/
} RGNOBJ;

/* device context*/
struct hdc {
	PSD		psd;		/* screen or memory device*/
	HWND		hwnd;		/* associated window*/
	DWORD		flags;		/* clipping flags*/
	int		bkmode;		/* background mode*/
	COLORVAL	bkcolor;	/* text background color*/
	COLORVAL	textcolor;	/* text color*/
	BRUSHOBJ *	brush;		/* current brush*/
	PENOBJ *	pen;		/* current pen*/
	FONTOBJ *	font;		/* current font*/
	BITMAPOBJ *	bitmap;		/* current bitmap (mem dc's only)*/
	RGNOBJ *	region;		/* user specified clip region*/
	int		drawmode;	/* rop2 drawing mode */
	POINT		pt;		/* current pen pos in client coords*/
};

/* cursor*/
struct hcursor {
	int		usecount;	/* use counter */
	SWCURSOR	cursor;		/* software cursor definition*/
};

/* window*/
struct hwnd {
	RECT		winrect;	/* window rect in screen coords*/
	RECT		clirect;	/* client rect in screen coords*/
	RECT		restorerc;	/* restore rect from maximized*/
	DWORD		style;		/* window style*/
	DWORD		exstyle;	/* window extended style*/
	PWNDCLASS	pClass;		/* window class*/
	struct hwnd	*parent;	/* parent window */
	struct hwnd	*children;	/* first child window */
	struct hwnd	*siblings;	/* next sibling window */
	struct hwnd	*next;		/* next window in complete list */
	struct hcursor	*cursor;	/* cursor for this window */
	struct hdc *	owndc;		/* owndc if CS_OWNDC*/
	int		unmapcount;	/* count of reasons not really mapped */
	int		id;		/* window id */
	CHAR		szTitle[64];	/* window title*/
	int		gotPaintMsg;	/* window had WM_PAINT PostMessage*/
	int		paintSerial;	/* experimental serial # for alphblend*/
#if UPDATEREGIONS
	MWCLIPREGION *	update;		/* update region in screen coords*/
#endif
	int		nextrabytes;	/* # window extra bytes*/
	char		extrabytes[1];	/* window extra bytes - must be last*/
};

/* gotPaintMsg values*/
#define PAINT_PAINTED		0	/* WM_PAINT msg has been processed*/
#define PAINT_NEEDSPAINT	1	/* WM_PAINT seen, paint when can*/
#define PAINT_DELAYPAINT	2	/* WM_PAINT seen,paint after user move*/

#ifdef __cplusplus
}
#endif
